@@ -1,7 +1,7 @@
 /*
  balloon.js -- a DHTML library for balloon tooltips
 
- $Id: balloon.js 23294 2010-05-31 21:21:01Z lstein $
+ $Id: balloon.js 24365 2011-01-14 15:39:25Z lstein $
 
  See http://www.gmod.org/wiki/index.php/Popup_Balloons
  for documentation.
@@ -198,8 +198,8 @@ Balloon.prototype.showTooltip = function(evt,caption,sticky,width,height) {
   document.body.appendChild(this.container);
   this.setStyle(this.container,'position','absolute');
   this.setStyle(this.container,'top',-8888);
-  this.setStyle(this.container,'font-family',this.fontFamily);
-  this.setStyle(this.container,'font-size',this.fontSize);
+  this.setStyle(this.container,'fontFamily',this.fontFamily);
+  this.setStyle(this.container,'fontSize',this.fontSize);
   this.container.innerHTML = unescape(this.currentHelpText);
 
   // make sure balloon image path is complete
@@ -295,7 +295,7 @@ Balloon.prototype.doShowTooltip = function() {
 
   if (!self.parent) {
     if (self.parentID) {
-      self.parent = document.getElementById(self.parentID);
+      self.parent = $(self.parentID);
     }
     else {
       self.parent = document.body;
@@ -316,11 +316,11 @@ Balloon.prototype.doShowTooltip = function() {
   var balloon = self.makeBalloon();
 
   // window dimensions
-  var pageWidth   = YAHOO.util.Dom.getViewportWidth();
+  var pageWidth   = document.viewport.getWidth();
   var pageCen     = Math.round(pageWidth/2);
-  var pageHeight  = YAHOO.util.Dom.getViewportHeight();
-  var pageLeft    = YAHOO.util.Dom.getDocumentScrollLeft();
-  var pageTop     = YAHOO.util.Dom.getDocumentScrollTop();
+  var pageHeight  = document.viewport.getHeight()
+  var pageLeft    = document.viewport.getScrollOffsets().left;
+  var pageTop     = document.viewport.getScrollOffsets().top;
   var pageMid     = pageTop + Math.round(pageHeight/2);
   self.pageBottom = pageTop + pageHeight;
   self.pageTop    = pageTop;
@@ -346,6 +346,10 @@ Balloon.prototype.doShowTooltip = function() {
   self.contents.appendChild(wrapper);
   wrapper.innerHTML = helpText;
 
+  // this partially fixes a bug in IE in which sticky balloons
+  // start failing to appear.
+  window.blur();
+
   // run any javascript in the thing -- sorry Sheldon
   if (self.evalScripts) {
      helpText.evalScripts();
@@ -377,7 +381,7 @@ Balloon.prototype.addCloseButton = function () {
   var closeWidth   = self.closeButtonWidth || 16;
   var balloonTop   = self.getLoc('balloon','y1') + margin + self.shadow;
   var BalloonLeft  = self.getLoc('topRight','x2') - self.closeButtonWidth - self.shadow - margin;
-  var closeButton  = document.getElementById('closeButton');
+  var closeButton  = $('closeButton');
 
   if (!closeButton) {
     closeButton = new Image;
@@ -399,7 +403,7 @@ Balloon.prototype.addCloseButton = function () {
   self.setStyle(closeButton,'left',BalloonLeft);
   self.setStyle(closeButton,'display','inline');
   self.setStyle(closeButton,'cursor','pointer');
-  self.setStyle(closeButton,'z-index',999999999);
+  self.setStyle(closeButton,'zIndex',999999999);
 }
 
 // use a fresh object every time to make sure style 
@@ -407,7 +411,7 @@ Balloon.prototype.addCloseButton = function () {
 Balloon.prototype.makeBalloon = function() {
   var self = currentBalloonClass;
 
-  var balloon = document.getElementById('balloon');
+  var balloon = $('balloon');
   if (balloon) {
     self.cleanup();
   }
@@ -448,7 +452,7 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
 
   self.setStyle(balloon,'position','absolute');
   self.setStyle(balloon,'top',-9999);
-  self.setStyle(balloon,'z-index',1000000);
+  self.setStyle(balloon,'zIndex',1000000);
 
   if (self.height) {
     self.setStyle('contentWrapper','height',self.height-fullPadding);
@@ -478,13 +482,13 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
     self.setStyle('contentWrapper','width',self.minWidth-fullPadding);
   }
   
-  self.setStyle('contents','z-index',2);
+  self.setStyle('contents','zIndex',2);
   self.setStyle('contents','color',self.fontColor);
-  self.setStyle('contents','font-family',self.fontFamily);
-  self.setStyle('contents','font-size',self.fontSize);
+  self.setStyle('contents','fontFamily',self.fontFamily);
+  self.setStyle('contents','fontSize',self.fontSize);
   self.setStyle('contents','background','url('+self.balloonImage+') top left no-repeat');
-  self.setStyle('contents','padding-top',fullPadding);
-  self.setStyle('contents','padding-left',fullPadding);
+  self.setStyle('contents','paddingTop',fullPadding);
+  self.setStyle('contents','paddingLeft',fullPadding);
 
   self.setStyle('bottomRight','background','url('+self.balloonImage+') bottom right no-repeat');
   self.setStyle('bottomRight','position','absolute');
@@ -492,7 +496,7 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
   self.setStyle('bottomRight','bottom',0-fullPadding);
   self.setStyle('bottomRight','height',fullPadding);
   self.setStyle('bottomRight','width',fullPadding);
-  self.setStyle('bottomRight','z-index',-1);
+  self.setStyle('bottomRight','zIndex',-1);
 
   self.setStyle('topRight','background','url('+self.balloonImage+') top right no-repeat');
   self.setStyle('topRight','position','absolute');
@@ -505,7 +509,7 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
   self.setStyle('bottomLeft','left',0);
   self.setStyle('bottomLeft','bottom',0-fullPadding);
   self.setStyle('bottomLeft','height',fullPadding);
-  self.setStyle('bottomLeft','z-index',-1);
+  self.setStyle('bottomLeft','zIndex',-1);
 
   if (this.stem) {
     var stem = document.createElement('img');
@@ -736,16 +740,16 @@ Balloon.prototype.cleanup = function() {
   var body;
   if (self) {
     body = self.parent   ? self.parent 
-         : self.parentID ? document.getElementById(self.parentID) || document.body
+         : self.parentID ? $(self.parentID) || document.body
          : document.body;
   }
   else {
     body = document.body;
   }
 
-  var bubble = document.getElementById('balloon');
-  var close  = document.getElementById('closeButton');
-  var cont   = document.getElementById('container');
+  var bubble = $('balloon');
+  var close  = $('closeButton');
+  var cont   = $('container');
   if (bubble) { body.removeChild(bubble) } 
   if (close)  { body.removeChild(close)  }
   if (cont)   { body.removeChild(cont)   }
@@ -859,7 +863,9 @@ Balloon.prototype.getEventTarget = function(event) {
   var e = event || window.event;
   if (e.target) targ = e.target;
   else if (e.srcElement) targ = e.srcElement;
-  if (targ.nodeType == 3) targ = targ.parentNode; // Safari
+  if (targ==null) targ=document.createElement('div');
+  if (targ.nodeType == 3) 
+      targ = targ.parentNode; // Safari
   return targ;
 }
 ////
@@ -870,11 +876,12 @@ Balloon.prototype.setStyle = function(el,att,val) {
     return false;
   }
   if (typeof(el) != 'object') {
-    el = document.getElementById(el);
+    el = $(el);
   }
   if (!el) {
     return false;
   }
+  el = Element.extend(el);
 
   if (val && att.match(/left|top|bottom|right|width|height|padding|margin/)) {
     val = new String(val);
@@ -884,31 +891,37 @@ Balloon.prototype.setStyle = function(el,att,val) {
   }
 
   // z-index does not work as expected
-  if (att == 'z-index') {
+  if (att == 'zIndex') {
     if (el.style) {
       el.style.zIndex = parseInt(val);
     }
   }
   else {
-    YAHOO.util.Dom.setStyle(el,att,val);
+    var style = {};
+    style[att] = val;
+    el.setStyle(style);
   }
 }
 
-// Uses YAHOO's region class for element coordinates
+
 Balloon.prototype.getLoc = function(el,request) {
-  var region = YAHOO.util.Dom.getRegion(el);
-
+  var offset = $(el).cumulativeOffset();
+  var dimensions = $(el).getDimensions();
   switch(request) {
-    case ('y1') : return parseInt(region.top);
-    case ('y2') : return parseInt(region.bottom);
-    case ('x1') : return parseInt(region.left);
-    case ('x2') : return parseInt(region.right);
-    case ('width')  : return (parseInt(region.right)  - parseInt(region.left));
-    case ('height') : return (parseInt(region.bottom) - parseInt(region.top));
-    case ('region') : return region; 
+    case ('y1') : return offset.top;
+    case ('y2') : return offset.top + dimensions.height;
+    case ('x1') : return offset.left;
+    case ('x2') : return offset.left + dimensions.width;
+    case ('width')  : return dimensions.width;
+    case ('height') : return dimensions.height;
+    case ('region') : 
+      var region = new Object;
+      region.y1 = offset.top;
+      region.y2 = offset.top + dimensions.height;
+      region.x1 = offset.left;
+      region.x2 = offset.left + dimensions.width;
+      return region; 
   }
-
-  return region;
 }
 
 // We don't know if numbers are overridden with strings
@@ -934,7 +947,7 @@ Balloon.prototype.showHide = function(visible) {
 
   // IE z-index bug fix (courtesy of Lincoln Stein)
   if (self.isOldIE()) {
-    var balloonContents = document.getElementById('contentWrapper');
+    var balloonContents = $('contentWrapper');
     if (!visible && balloonContents) {
       var balloonSelects = balloonContents.getElementsByTagName('select');
       var myHash = new Object();
@@ -978,21 +991,18 @@ Balloon.prototype.isOverlap = function(el1,el2) {
   var R1 = this.getLoc(el1,'region');
   var R2 = this.getLoc(el2,'region');
   if (!R1 || !R2) return false;
-  var intersect = R1.intersect(R2);
-  if (intersect) {
-    // extent of overlap;
-    intersect = new Array((intersect.right - intersect.left),(intersect.bottom - intersect.top));
+
+  if ((R1.x1 < R2.x2) && (R1.x2 > R2.x1) && (R1.y1 < R2.y2) && (R1.y2 > R2.y1)) { 
+    return new Array((R1.x1 < R2.x1 ? R1.x2 - R2.x1 : R2.x2 - R1.x1),(R1.y1 < R2.y1 ? R1.y2 - R2.y1 : R2.y2 - R1.y1));
+  } else {
+    return false;
   }
-  return intersect;
 }
 
-// Coordinate-based test for the same element
+// Test for the same element
 Balloon.prototype.isSameElement = function(el1,el2) {
   if (!el1 || !el2) return false;
-  var R1 = this.getLoc(el1,'region');
-  var R2 = this.getLoc(el2,'region');
-  var same = R1.contains(R2) && R2.contains(R1);
-  return same ? true : false;
+  return el1 == el2;
 }
 
 
@@ -1033,8 +1043,8 @@ Please contact the site administrator for assistance.';
   // check if the contents are to be retrieved from an element
   if (caption.match(/^load:/)) {
     var load = caption.split(':');
-    if (!document.getElementById(load[1])) alert ('problem locating element '+load[1]);
-    caption = document.getElementById(load[1]).innerHTML;
+    if (!$(load[1])) alert ('problem locating element '+load[1]);
+    caption = $(load[1]).innerHTML;
     this.loadedFromElement = true;
   }
 
@@ -1130,4 +1140,4 @@ Balloon.prototype.isKonqueror = function() {
 // and Google chrome
 Balloon.prototype.isChrome = function() {
   return navigator.userAgent.toLowerCase().indexOf('chrome') > -1;
-}
\ No newline at end of file
+}
