@@ -4,7 +4,7 @@
                       This class handles details-specific configuration.
 
  Sheldon McKay <mckays@cshl.edu>
- $Id: detailSelect.js 22257 2009-11-16 15:11:04Z lstein $
+ $Id: detailSelect.js 24370 2011-01-14 20:01:01Z lstein $
 
 */
 
@@ -29,41 +29,19 @@ Details.prototype = new SelectArea();
 Details.prototype.initialize = function() {
   var self = new Details;
   
-  var i = document.getElementById(self.imageId);
+  var i = $(self.imageId);
   if (!i) return false;
 
   i = self.replaceImage(i);
   
 
-  //var p = document.getElementById('panels');
-  var p = i.parentNode;
+  //var p = $('panels');
+  var p = i.parentNode.parentNode;
   self.height      = self.elementLocation(i,'height');
   self.panelHeight = self.elementLocation(p,'height');
   self.width       = self.elementLocation(i,'width');
   self.selectLayer = p.parentNode.parentNode;
 
-  self.top     = self.elementLocation(i,'y1');
-  self.bottom  = self.elementLocation(i,'y2');
-  self.left    = self.elementLocation(i,'x1');
-  self.right   = self.elementLocation(i,'x2');
-
-//   try {
-//       detailBalloon = new Balloon();
-//       detailBalloon.vOffset  = 1;
-//       detailBalloon.showOnly = 2; // just show twice
-//       var helpFunction = function(event) {
-// 	  if (!event) {
-// 	      event = window.event;
-// 	  }
-// 	  var help = '<b>Scalebar:</b> Click here to recenter or click and drag left or right to select a region';
-// 	  detailBalloon.showTooltip(event,help,0,250);
-//       }
-//       i.onmouseover = helpFunction;
-//   }
-//   catch(e) {
-//       i.setAttribute('title','click and drag to select a region');
-//   }
-
   self.scalebar = i;
   self.addSelectMenu('detail');
   self.addSelectBox('detail');
@@ -78,15 +56,15 @@ Details.prototype.startSelection = function(event) {
 
 Details.prototype.loadSegmentInfo = function() {
   // get the segment info from gbrowse CGI parameters
-  
-  var i = document.getElementById(self.imageId);
+  var self = detailsObject;
+  var i = $(self.imageId);
   
   var segment_info = Controller.segment_info;
 
   this.ref          = segment_info.ref;
   this.segmentStart = parseInt(segment_info.detail_start);
   this.segmentEnd   = parseInt(segment_info.detail_stop);
-  this.flip         = document.sliderform.flip.checked;
+  this.flip         = segment_info.flip;
   this.padLeft      = parseInt(segment_info.image_padding);
   this.pixelToDNA   = parseFloat(segment_info.details_pixel_ratio);
   this.detailStart  = parseInt(segment_info.detail_start);
@@ -102,7 +80,7 @@ Details.prototype.loadSegmentInfo = function() {
 
   // We fetch the left margin again because the controller can change 
   // the size & position of the section after it is created.
-  this.left       = this.elementLocation(document.getElementById(this.imageId),'x1');
+  this.left       = this.elementLocation($(this.imageId),'x1') - this.elementLocation(this.selectLayer,'x1');
 
   this.pixelStart   = this.left  + this.padLeft;
 }
@@ -120,18 +98,18 @@ Details.prototype.formatMenu = function() {
          </tr>\
          <tr>\
            <td>\
-             <a href="javascript:SelectArea.prototype.clearAndSubmit()">Zoom in</a>\
+             <a href="javascript:SelectArea.prototype.clearAndSubmit()">' + Controller.translate('ZOOM_IN') + '</a>\
            </td>\
          </tr>\
          <tr>\
            <td>\
-             <a href="javascript:SelectArea.prototype.clearAndRecenter()">Recenter on this region</a>\
+             <a href="javascript:SelectArea.prototype.clearAndRecenter()">' + Controller.translate('RECENTER_ON_REGION') + '</a>\
            </td>\
          </tr>\
          <tr>\
            <td onmouseup="SelectArea.prototype.cancelRubber()">\
              <a href="?plugin=FastaDumper;plugin_action=Go;name=SELECTION" target="_new">\
-              Dump selection as FASTA\
+              ' + Controller.translate('DUMP_AS_FASTA') + '\
              </a>\
            </td>\
          </tr>\
