@@ -3,7 +3,7 @@
  rubber.js -- a base class for drag/rubber-band selection in gbrowse
 
  Sheldon McKay <mckays@cshl.edu>
- $Id: rubber.js 23858 2010-09-28 14:32:39Z lstein $
+ $Id: rubber.js 24370 2011-01-14 20:01:01Z lstein $
 
 */
 
@@ -40,11 +40,13 @@ SelectArea.prototype.replaceImage = function(image) {
   // escape backslashes that may appear in the src attribute
   src = escape(src.replace(/\\/g,"\\\\"));
 
-  YAHOO.util.Dom.setStyle(image,'background', 'url('+src+') top left no-repeat');
-  YAHOO.util.Dom.setStyle(image,'width', width+'px');
-  YAHOO.util.Dom.setStyle(image,'height', height+'px');
-  YAHOO.util.Dom.setStyle(image,'display','block');
-  YAHOO.util.Dom.setStyle(image,'cursor','text');
+  image = Element.extend(image);
+  image.setStyle({ background: 'url('+src+') top left no-repeat',
+                   width: width+'px',
+                   height: height+'px',
+                   display: 'block',
+                   cursor: 'text' 
+  });
 
 
   if (   !document.searchform 
@@ -74,8 +76,9 @@ SelectArea.prototype.replaceImage = function(image) {
       for (var n=0;n<map.length;n++) {
         var newTop   = this.elementLocation(map[n],'y1') + top;
         var newLeft  = this.elementLocation(map[n],'x1') + left;
-        YAHOO.util.Dom.setStyle(map[n],'top',newTop+'px');
-        YAHOO.util.Dom.setStyle(map[n],'left',newLeft+'px');
+        map[n].setStyle({ top: newTop+'px',
+                          left: newLeft+'px'
+        });
       }
     }
   }
@@ -92,10 +95,8 @@ SelectArea.prototype.recenter = function(event) {
   var coord  = self.flip ? Math.round(self.segmentEnd - deltaSequenceStart)
                          : Math.round(self.segmentStart + deltaSequenceStart);
 
-  var detailsStart = parseInt(self.detailStart);
-  var detailsEnd = parseInt(self.detailEnd);
   var end  = self.segmentEnd;
-  var span = Math.abs(detailsEnd - detailsStart);
+  var span = Math.abs(TrackPan.viewable_segment_length);
   var half = Math.round(span/2);
 
   // don't fall off the ends
@@ -109,24 +110,31 @@ SelectArea.prototype.recenter = function(event) {
     end = start;
     start = tmp;
   }
-    
-  self.currentSegment = self.ref + ':' + start + '..' + end;
-  if (document.searchform) {
-    document.searchform.name.value = self.currentSegment;
+  
+  if (start >= this.detailStart && end <= this.detailEnd) {
+    // The segment is already loaded - just scroll to it
+    var scroll_to = TrackPan.position_from_start(start);
+    TrackPan.update_pan_position(scroll_to); 
+  } else {
+    self.currentSegment = self.ref + ':' + start + '..' + end;
+    if (document.searchform) {
+      document.searchform.name.value = self.currentSegment;
+    }
+    self.submit();
   }
-  self.submit();
 }
 
 // Cross-browser element coordinates
 SelectArea.prototype.elementLocation = function(el,request) {
-  var region = YAHOO.util.Dom.getRegion(el);
+  var offset = $(el).cumulativeOffset();
+  var dimensions = $(el).getDimensions();
   switch(request) {
-    case ('y1') : return region.top;
-    case ('y2') : return region.bottom;
-    case ('x1') : return region.left;
-    case ('x2') : return region.right;
-    case ('width')  : return (region.right - region.left);
-    case ('height') : return (region.bottom - region.top);
+    case ('y1') : return offset.top;
+    case ('y2') : return offset.top + dimensions.height;
+    case ('x1') : return offset.left;
+    case ('x2') : return offset.left + dimensions.width;
+    case ('width')  : return dimensions.width;
+    case ('height') : return dimensions.height;
  }
 }
 
@@ -168,27 +176,21 @@ SelectArea.prototype.startRubber = function(self,event) {
   // deal with drag/select artifacts
   self.disableSelection(self.selectLayer);
 
-  self.selectPixelStart = self.eventLocation(event,'x');
+  self.selectPixelStart = self.eventLocation(event,'x') - self.elementLocation(self.selectLayer,'x1');
 
-  YAHOO.util.Dom.setStyle(self.selectBox,'visibility','hidden');
-  YAHOO.util.Dom.setStyle(self.selectBox,'left',self.selectPixelStart+'px');
-  YAHOO.util.Dom.setStyle(self.selectBox,'width','2px');
-  YAHOO.util.Dom.setStyle(self.selectBox,'text-align', 'center');	
-  YAHOO.util.Dom.setStyle(self.selectMenu,'visibility','hidden');
-  
-  // height of select box to match height of detail panel
-  var h = self.elementLocation(self.selectLayer,'height');
-  YAHOO.util.Dom.setStyle(self.selectBox,'height',h+'px');
-  
-  // vertical offset may also need adjusting
-  var t = self.elementLocation(self.selectLayer,'y1');
-  YAHOO.util.Dom.setStyle(self.selectBox,'top',t+'px');
+  self.selectBox.setStyle({ visibility: 'hidden',
+                            left: self.selectPixelStart+'px',
+                            width: '2px',
+                            textAlign: 'center',
+                            visibility: 'hidden' 
+  });
 
-  var spanReport = self.spanReport || self.createAndAppend('p',self.selectBox,'spanReport');
-  YAHOO.util.Dom.setStyle(spanReport,'color',self.fontColor||'black');
-  YAHOO.util.Dom.setStyle(spanReport,'margin-top',self.marginTop||'0px');
-  YAHOO.util.Dom.setStyle(spanReport,'background','transparent');
-  YAHOO.util.Dom.setStyle(spanReport,'font','normal bold 14px sans-serif');
+  var spanReport = Element.extend(self.spanReport || self.createAndAppend('p',self.selectBox,'spanReport'));
+  spanReport.setStyle({ color: self.fontColor||'black',
+                        marginTop: self.marginTop||'0px',
+                        background: 'transparent',
+                        font: 'normal bold 14px sans-serif'
+  });
 
   spanReport.innerHTML = ' ';
   self.spanReport = spanReport;
@@ -201,8 +203,8 @@ SelectArea.prototype.cancelRubber = function() {
 
   if (!self.selectBox) return false;
   
-  YAHOO.util.Dom.setStyle(self.selectBox,'visibility','hidden');
-  YAHOO.util.Dom.setStyle(self.selectMenu,'visibility','hidden');
+  self.selectBox.setStyle({visibility:'hidden'});
+  self.selectMenu.setStyle({visibility:'hidden'});
   selectAreaIsActive = false;
 
   if (self.originalLandmark) {
@@ -223,7 +225,7 @@ SelectArea.prototype.moveRubber = function(event) {
 
   var self = currentSelectArea;
   var selectPixelStart = self.selectPixelStart;
-  var selectPixelEnd   = self.eventLocation(event,'x');
+  var selectPixelEnd   = self.eventLocation(event,'x') - self.elementLocation(self.selectLayer,'x1');
   var selectPixelWidth = Math.abs(selectPixelStart - selectPixelEnd);
 
   var rev, left;
@@ -281,10 +283,10 @@ SelectArea.prototype.moveRubber = function(event) {
   } 
 
   // size and appearance of the "rubber band" select box
-  YAHOO.util.Dom.setStyle(self.selectBox,'width','1px');
-  YAHOO.util.Dom.setStyle(self.selectBox,'left',left+'px');
-  YAHOO.util.Dom.setStyle(self.selectBox,'width',selectPixelWidth+'px');
-  YAHOO.util.Dom.setStyle(self.selectBox,'visibility','visible');
+  self.selectBox.setStyle({left: left+'px',
+                           width: selectPixelWidth+'px',
+                           visibility: 'visible'
+  });
 
   // warning if max segment size exceeded
   var tooBig;
@@ -345,7 +347,7 @@ SelectArea.prototype.disableSelection = function(el) {
 // Builds the popup menu that appears when selection is complete
 SelectArea.prototype.addSelectMenu = function(view) {
 
-  var menu =  document.getElementById(view+'SelectMenu'); 
+  var menu =  $(view+'SelectMenu'); 
   if (menu) {
     this.autoSubmit = false;
   }
@@ -354,18 +356,20 @@ SelectArea.prototype.addSelectMenu = function(view) {
   }
 
   // required style 
-  YAHOO.util.Dom.setStyle(menu,'position','absolute');
-  YAHOO.util.Dom.setStyle(menu,'display','block');
-  YAHOO.util.Dom.setStyle(menu,'z-index','101');
-  YAHOO.util.Dom.setStyle(menu,'visibility','hidden');
+  menu = Element.extend(menu);
+  menu.setStyle({ position: 'absolute',
+                  display: 'block',
+                  zIndex: '101',
+                  visibility: 'hidden'
+  });
 
   // optional style -- check if a custom menu has styles set already
   var existingStyle = new String(menu.getAttribute('style'));
   if (existingStyle) {
-    if (!existingStyle.match(/width/i))      YAHOO.util.Dom.setStyle(menu,'width',this.menuWidth||'200px');
-    if (!existingStyle.match(/font/i))       YAHOO.util.Dom.setStyle(menu,'font','12px sans-serif');
-    if (!existingStyle.match(/background/i)) YAHOO.util.Dom.setStyle(menu,'background','lightyellow');
-    if (!existingStyle.match(/border/i))     YAHOO.util.Dom.setStyle(menu,'border','1px solid #003366');
+    if (!existingStyle.match(/width/i))      menu.setStyle({ width: this.menuWidth||'200px'});
+    if (!existingStyle.match(/font/i))       menu.setStyle({ font: '12px sans-serif'});
+    if (!existingStyle.match(/background/i)) menu.setStyle({ background: 'lightyellow'});
+    if (!existingStyle.match(/border/i))     menu.setStyle({ border: '1px solid #003366'});
   }
 
   this.selectMenu = menu;
@@ -378,18 +382,17 @@ SelectArea.prototype.addSelectBox = function(view) {
   if (this.selectBox) return false;
  
   var box = this.createAndAppend('div',this.selectLayer,view+'selectBox');
-
-  YAHOO.util.Dom.setStyle(box,'position','absolute');
-// this was breaking IE for some reason
-//  YAHOO.util.Dom.setStyle(box,'display', 'inline');
-  YAHOO.util.Dom.setStyle(box,'visibility', 'hidden');
-  YAHOO.util.Dom.setStyle(box,'top',this.top+'px');
-  YAHOO.util.Dom.setStyle(box,'left','0px');
-  YAHOO.util.Dom.setStyle(box,'z-index',100);
-  YAHOO.util.Dom.setStyle(box,'border',this.border||'none');
+  box     = Element.extend(box);
+  box.setStyle({ position: 'absolute',
+                 visibility: 'hidden',
+                 top: '0px',
+                 height: '100%',
+                 left: '0px',
+                 zIndex: 100,
+                 border: this.border||'none' });
 
   // click on scalebar initializes selection
-  this.scalebar.onmousedown = this.startSelection;
+  this.scalebar.onmousedown      = this.startSelection;
 
   // drag and mouseup on details panel fires menu
   this.selectLayer.onmousemove   = this.moveRubber;
@@ -462,7 +465,7 @@ SelectArea.prototype.showMenu = function(event) {
   var menu = self.selectMenu;
   menu.innerHTML = self.menuHTML.replace(/SELECTION/g,self.currentSegment);
 
-  var pageWidth  = YAHOO.util.Dom.getViewportWidth();
+  var pageWidth  = document.viewport.getWidth();
   var menuWidth  = self.elementLocation(menu,'width');
   var menuHeight = self.elementLocation(menu,'height');
   var menuYHalf  = Math.round(menuHeight/2); 
@@ -471,25 +474,27 @@ SelectArea.prototype.showMenu = function(event) {
   if ((left+menuWidth) > pageWidth) left -= menuWidth + 10;
   var top  = self.eventLocation(event,'y') - menuYHalf;
 
-  YAHOO.util.Dom.setStyle(menu,'top',  top+'px'); 
-  YAHOO.util.Dom.setStyle(menu,'left', left+'px');
+  menu = Element.extend(menu);
+  menu.setStyle({ top:  top+'px' }); 
+  menu.setStyle({ left: left+'px' });
 
   // Abort if there is no selection
-  if (YAHOO.util.Dom.getStyle(self.selectBox,'visibility') == 'hidden') {
+  if (self.selectBox.getStyle('visibility') == 'hidden') {
     self.cancelRubber;
     return false;
   }
 
-  YAHOO.util.Dom.setStyle(menu,'visibility','visible');
+  menu.setStyle({ visibility: 'visible' });
 
 }
 
 SelectArea.prototype.hideMenu = function() {
   var self = currentSelectArea;
 
-  YAHOO.util.Dom.setStyle(self.selectBox,'width',1);  
-  YAHOO.util.Dom.setStyle(self.selectBox,'visibility','hidden');
-  YAHOO.util.Dom.setStyle(self.selectMenu,'visibility','hidden');
+  self.selectBox.setStyle({ width: 1,
+                            visibility: 'hidden'
+  });
+  self.selectMenu.setStyle({visibility: 'hidden'});
 }
 
 SelectArea.prototype.clearAndSubmit = function(plugin,action) {
@@ -530,18 +535,10 @@ SelectArea.prototype.setOpacity = function(el,opc,bgColor) {
   
   if (!(el && opc)) return false;
 
-  // Just an outline for Konqueror
-  //  if (navigator.userAgent.indexOf( 'Konqueror' ) != -1) {
-  //     YAHOO.util.Dom.setStyle(el,'border','1px solid black');
-  //    return false;
-  //  }
-
   opc = parseFloat(opc);
-  YAHOO.util.Dom.setStyle(el,'background',bgColor||'#BABABA');
-  YAHOO.util.Dom.setStyle(el,'opacity',opc);
-  YAHOO.util.Dom.setStyle(el,'filter','alpha(opacity= '+(100*opc)+')');
-  YAHOO.util.Dom.setStyle(el,'MozOpacity',opc);
-  YAHOO.util.Dom.setStyle(el,'KhtmlOpacity',opc);
+  el.setStyle({ background: bgColor||'#BABABA',
+                opacity: opc 
+             });
 }
 
 
