@@ -94,6 +94,11 @@ sub ACTION_demo {
 	    s!\$TMP!$dir/tmp!g;
 	    s/\$CGIURL/$cgiurl/g;
 	    s!\$VERSION!$self->dist_version!eg;
+	    s/\$CAN_USER_ACCOUNTS_OPENID/$self->has_openid/eg;
+	    s/\$CAN_USER_ACCOUNTS_REG/$self->has_smtp/eg;
+	    s/\$CAN_USER_ACCOUNTS/$self->has_mysql_or_sqlite/eg;
+	    s/\$USER_ACCOUNT_DB/$self->guess_user_account_db/eg;
+	    s/\$SMTP_GATEWAY/$self->guess_smtp_gateway/eg;
 	    s!^url_base\s*=.+!url_base               = /!g;
 	    $out->print($_);
 	}
@@ -365,6 +370,11 @@ ScriptAlias  "/gb2"      "$cgibin"
     Options      ExecCGI
   </Location>
   DefaultInitEnv GBROWSE_CONF $conf
+  # these directives prevent idle/busy timeouts and may need to be
+  # adjusted up or down
+  FcgidMinProcessesPerClass 6
+  FcgidIOTimeout   600
+  FcgidBusyTimeout 600
   $fcgid_inc
 </IfModule>
 
@@ -374,7 +384,9 @@ ScriptAlias  "/gb2"      "$cgibin"
     SetHandler   fastcgi-script
     Options      ExecCGI
   </Location>
-  FastCgiConfig $fcgi_inc -initial-env GBROWSE_CONF=$conf
+  # Note: you may need to increase -idle-timeout if file uploads are timing out and returning server
+  # errors.
+  FastCgiConfig -idle-timeout 600 -maxClassProcesses 20 $fcgi_inc -initial-env GBROWSE_CONF=$conf 
 </IfModule>
 
 <IfModule mod_perl.c>
@@ -449,14 +461,20 @@ sub ACTION_install {
 
     my $base = basename($self->install_path->{htdocs});
 
+    # Configure the databases, if needed.
+    print STDERR "Updating user account database...\n";
+    my $metadb_script = File::Spec->catfile("bin", "gbrowse_metadb_config.pl");
+    system 'perl',$metadb_script;
+
     if (Module::Build->y_n(
 	    "It is recommended that you restart Apache. Shall I try this for you?",'y'
 	)) {
 	system "sudo /etc/init.d/apache2 restart";
     }
-
+    
     print STDERR "\n***INSTALLATION COMPLETE***\n";
-    print STDERR "Load http://localhost/$base for demo and documentation\n";
+    print STDERR "Load http://localhost/$base for demo and documentation.\n";
+    print STDERR "Visit the http://gmod.org for more information on setting up databases for users and custom tracks.\n";
 }
 
 sub ACTION_install_slave {
@@ -514,7 +532,7 @@ sub process_conf_files {
 	    my $installed = File::Spec->catfile($install_path,$new);
 	    if (-e $installed && $base =~ /\.conf$/ && (compare($base,$installed) != 0)) {
 		warn "$installed conf file is already installed. New version will be installed as $installed.new\n";
-		copy ("blib/$base","blib/$base.new");
+		rename ("blib/$base","blib/$base.new");
 		print $skip '^',"blib/",quotemeta($base),'$',"\n";
 	    }
 	}
@@ -533,10 +551,6 @@ sub process_htdocs_files {
 	$self->substitute_in_place("blib/$_")
 	    if $copied
 	    or !$self->up_to_date('_build/config_data',"blib/$_");
-# was  trying to do something about localizing installed perl, but forget what it was
-#	if (/\.pl$/ && $copied) {
-#	    
-#	}
     }
 }
 
@@ -582,7 +596,7 @@ sub process_etc_files {
 		my $installed = File::Spec->catfile($install_path,$new);
 		if (-e $installed) {
 		    warn "$installed is already installed. New version will be installed as $installed.new\n";
-		    copy ("blib/$base","blib/$base.new");
+		    rename ("blib/$base","blib/$base.new");
 		    print $skip '^',"blib/",quotemeta($base),'$',"\n";
 		}
 	    }
@@ -654,7 +668,7 @@ sub substitute_in_place {
     my $wwwuser  = $self->config_data('wwwuser');
     my $perl5lib = $self->perl5lib || '';
     my $installscript = $self->scriptdir;
-    my $cgiurl   = $self->cgiurl;
+    my $cgiurl        = $self->cgiurl;
 
     while (<$in>) {
 	s/\$INSTALLSCRIPT/$installscript/g;
@@ -666,6 +680,11 @@ sub substitute_in_place {
 	s/\$WWWUSER/$wwwuser/g;
 	s/\$DATABASES/$databases/g;
 	s/\$VERSION/$self->dist_version/eg;
+	s/\$CAN_USER_ACCOUNTS_OPENID/$self->has_openid/eg;
+	s/\$CAN_USER_ACCOUNTS_REG/$self->has_smtp/eg;
+	s/\$CAN_USER_ACCOUNTS/$self->has_mysql_or_sqlite/eg;
+	s/\$USER_ACCOUNT_DB/$self->guess_user_account_db/eg;
+	s/\$SMTP_GATEWAY/$self->guess_smtp_gateway/eg;
 	s/\$TMP/$tmp/g;
 	$out->print($_);
     }
@@ -674,6 +693,38 @@ sub substitute_in_place {
     rename("$path.$$",$path);
 }
 
+sub has_mysql_or_sqlite {
+    my $self = shift;
+    return eval "require DBD::mysql; 1" || eval "require DBD::SQLite; 1" || 0;
+}
+
+sub has_smtp {
+    my $self = shift;
+    return eval "require Net::SMTP; 1" || 0;
+}
+
+sub has_openid {
+    my $self = shift;
+    return eval "require Net::OpenID::Consumer; require LWP::UserAgent; 1" || 0;
+}
+
+sub guess_user_account_db {
+    my $self = shift;
+    if (eval "require DBD::mysql; 1") {
+	return 'DBI:mysql:gbrowse_login;user=gbrowse;password=gbrowse';
+    } elsif (eval "require DBD::SQLite; 1") {
+	my $databases = $self->install_path->{'databases'};
+	return "DBI:SQLite:$databases/users.sqlite";
+    } else {
+	return "no database defined # please correct this";
+    }
+}
+
+sub guess_smtp_gateway {
+    my $self = shift;
+    return 'localhost  # this assumes that a correctly configured smtp server is running on current machine; change if necessary';
+}
+
 sub private_props {
     return \%OK_PROPS;
 }
