@@ -1,8 +1,8 @@
 package Bio::Graphics::Browser2;
-# $Id: Browser2.pm 24190 2010-11-18 17:05:23Z lstein $
+# $Id: Browser2.pm 24378 2011-01-17 22:25:41Z lstein $
 # Globals and utilities for GBrowse and friends
 
-our $VERSION = '2.17';
+our $VERSION = '2.20';
 
 use strict;
 use warnings;
@@ -16,12 +16,13 @@ use File::Path 'mkpath';
 use Bio::Graphics::Browser2::DataSource;
 use Bio::Graphics::Browser2::Session;
 use GBrowse::ConfigData;
-use Carp 'croak','carp','confess';
+use Carp qw(croak carp confess cluck);
 
 use constant DEFAULT_MASTER => 'GBrowse.conf';
 
 my (%CONFIG_CACHE,$HAS_DBFILE,$HAS_STORABLE);
 
+# Open a globals object with a config file in the standard location.
 sub open_globals {
     my $self = shift;
     my $conf_dir  = $self->config_base;
@@ -34,8 +35,7 @@ sub new {
   my $class            = shift;
   my $config_file_path = shift;
 
-  # this code caches the config info so that we don't need to 
-  # reparse in persistent (e.g. modperl) environment
+  # Cache the config info so we don't need to reparse in a persistent (e.g. modperl) environment
   my $mtime            = (stat($config_file_path))[9] || 0;
   if (exists $CONFIG_CACHE{$config_file_path}
       && $CONFIG_CACHE{$config_file_path}{mtime} >= $mtime) {
@@ -116,7 +116,7 @@ sub openid_url  { shift->url_path('openid')             }
 sub js_url      { shift->url_path('js')                 }
 sub help_url    { shift->url_path('gbrowse_help')       }
 sub stylesheet_url   { shift->url_path('stylesheet')    }
-
+sub auth_plugin { shift->setting(general=>'authentication plugin') }
 
 # this returns the base URL and path info for use in constructing
 # links. For example, if gbrowse is running at http://foo.bar/cgi-bin/gb2/gbrowse/yeast,
@@ -132,8 +132,10 @@ sub gbrowse_base {
 
 # this returns the URL of the "master" gbrowse instance
 sub gbrowse_url {
-    my $self   = shift;
+    my $self            = shift;
+    my $fallback_source = shift;
     my ($base,$source) = $self->gbrowse_base;
+    $source          ||= $fallback_source if $fallback_source;
     return "$base/gbrowse/$source";
 }
 
@@ -159,6 +161,13 @@ sub user_dir {
     return $self->tmpdir('userdata',@components);
 }
 
+sub admin_dir {
+    my $self = shift;
+    my @components = @_;
+    my $path = $self->admin_dbs();
+    return File::Spec->catfile($path,@components);
+}
+
 sub tmpimage_dir {
     my $self  = shift;
     return $self->tmpdir('images',@_);
@@ -231,10 +240,26 @@ sub application_name       { shift->setting(general=>'application_name')      ||
 sub application_name_long  { shift->setting(general=>'application_name_long') || 'The Generic Genome Browser' }
 sub email_address          { shift->setting(general=>'email_address')         || 'noreply@gbrowse.com'        }
 sub smtp                   { shift->setting(general=>'smtp_gateway')          || 'smtp.res.oicr.on.ca'        }
-sub user_account_db        { shift->setting(general=>'user_account_db')       
-				   || 'DBI:mysql:gbrowse_login;user=gbrowse;password=gbrowse'  }
-sub admin_account          { shift->setting(general=>'admin_account') }
-sub admin_dbs              { shift->setting(general=>'admin_dbs')     }
+sub user_account_db        { shift->setting(general=>'user_account_db')                                       } # Used by uploads & user databases, they set their own defaults.
+sub user_accounts	   { my $self = shift;
+			     return $self->setting(general=>'user_accounts') ||
+				    $self->setting(general=>'user_accounts')  || 
+				    0; }
+sub user_accounts_allow_registration
+                           { 
+			       my $val = shift->setting(general=>'user_accounts_registration');
+			       return 1 unless defined $val;
+			       return $val;
+			   }
+sub user_accounts_allow_openid
+                           { 
+			       my $val = shift->setting(general=>'user_accounts_openid');
+			       return 1 unless defined $val;
+			       return $val;
+			   }
+sub public_files           { shift->setting(general=>'public_files')          || 10                           }
+sub admin_account          { shift->setting(general=>'admin_account')                                         }
+sub admin_dbs              { shift->setting(general=>'admin_dbs')                                             }
 sub openid_secret {
     return GBrowse::ConfigData->config('OpenIDConsumerSecret')
 }
@@ -242,7 +267,9 @@ sub openid_secret {
 # uploads
 sub upload_db_adaptor {
     my $self = shift;
-    return $self->setting(general=>'upload_db_adaptor') || $self->setting(general=>'userdb_adaptor');
+    my $adaptor = $self->setting(general=>'upload_db_adaptor') || $self->setting(general=>'userdb_adaptor');
+    warn "The upload_db_adaptor in your Gbrowse.conf file isn't in the DBI::<module> format: remember, it's not a connection string." if $adaptor =~ /^DBI/ && $adaptor !~ /(^DBI::+)/i;
+    return $adaptor;
 }
 sub upload_db_host {
     my $self = shift;
@@ -282,7 +309,7 @@ sub session_args    {
 
 ## methods for dealing with data sources
 sub data_sources {
-  return sort grep {!/^\s*=~/} shift->SUPER::configured_types();
+  return sort grep {!/^\s*=~/ && !/:plugin$/} shift->SUPER::configured_types();
 }
 
 sub data_source_description {
@@ -291,10 +318,22 @@ sub data_source_description {
   return $self->setting($dsn=>'description');
 }
 
+sub data_source_restrict {
+  my $self = shift;
+  my $dsn  = shift;
+  return $self->setting($dsn=>'restrict');
+}
+
 sub data_source_show {
     my $self = shift;
-    my $dsn  = shift;
+    my $dsn      = shift;
+    my ($username,$authenticator) = @_;
     return if $self->setting($dsn=>'hide');
+
+    # because globals are cached between use, we do not want usernames
+    # to be defined outside the scope of this call
+    local $self->{'.authenticated_username'} = $username      if defined $username;
+    local $self->{'.authenticator'}          = $authenticator if defined $authenticator;
     return $self->authorized($dsn);
 }
 
@@ -314,6 +353,15 @@ sub data_source_path {
   $self->resolve_path($path,'config');
 }
 
+sub authorized {
+    my $self = shift;
+    my $sourcename = shift;
+    my ($username,$authenticator)   = @_;
+    local $self->{'.authenticated_username'} = $username      if defined $username;
+    local $self->{'.authenticator'}          = $authenticator if defined $authenticator;
+    return $self->SUPER::authorized($sourcename);
+}
+
 sub create_data_source {
   my $self = shift;
   my $dsn  = shift;
@@ -380,14 +428,12 @@ sub update_data_source {
     $session->source($new_source);
     $source = $new_source;
   } else {
-    carp "Invalid source $new_source";
     my $fallback_source = $self->valid_source($old_source) 
 	? $old_source
 	: $self->default_source;
     $session->source($fallback_source);
     $source = $fallback_source;
   }
-
   return $source;
 }
 
@@ -439,7 +485,7 @@ sub authorized_session {
   if ($session->match_nonce($authority,CGI::remote_addr())) {
       return $session;
   } else {
-      warn "UNAUTHORIZED ATTEMPT";
+      cluck "UNAUTHORIZED ATTEMPT";
       return $self->session('xyzzy');
   }
 }
